@@ -250,7 +250,7 @@ def planetstabm(date):
 
 
 def starstab(date):
-    # returns a table with ephemerieds for the navigational stars
+    # returns a table with ephemerides for the navigational stars
     # OLD: \begin{tabular*}{0.251\textwidth}[t]{@{\extracolsep{\fill}}|rrr|}
     # OLD: note: 0.251 instead of 0.25 (above) prevents an "Overfull \hbox (0.14297pt too wide)" message on about 5 specific pages in the full year (moonimg=True)
 
@@ -923,7 +923,6 @@ def lunatikz(phase, dfcm):
         end_angle = 270
         xradius = cos(phase) * radius
 
-    dfcm = dfcm.replace("\\","\\\\")
     tikz = r'''\multicolumn{{1}}{{|c|}}{{\multirow{{3}}{{*}}
 {{\begin{{tikzpicture}}
 \node[anchor=south west,inner sep=0] at (0,0) {{\includegraphics[width=0.75cm]{{{}}}}};
@@ -1137,8 +1136,6 @@ def almanac(first_day, pagenum, df180, df360, dfcm):
 % for the title page only...
 \newgeometry{{nomarginpar, top={}, bottom={}, left={}, right={}}}'''.format(tm1,bm1,lm1,rm1)
 
-    df180 = df180.replace("\\","\\\\")
-    df360 = df360.replace("\\","\\\\")
     alm = alm + r'''
     \begin{{titlepage}}
     \begin{{center}}
